==> openshift-model-storageversionmigrator-5.10.2-sources.jar: io/fabric8/openshift/api/model/storageversionmigrator/v1alpha1/StorageStateStatusFluentImpl.java <==
package io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class StorageStateStatusFluentImpl<A extends io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateStatusFluent<A>{
  public StorageStateStatusFluentImpl() {
  }
  public StorageStateStatusFluentImpl(io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateStatus instance) {
    this.withCurrentStorageVersionHash(instance.getCurrentStorageVersionHash()); 
    this.withLastHeartbeatTime(instance.getLastHeartbeatTime()); 
    this.withPersistedStorageVersionHashes(instance.getPersistedStorageVersionHashes()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String currentStorageVersionHash;
  private java.lang.String lastHeartbeatTime;
  private java.util.List<java.lang.String> persistedStorageVersionHashes = new java.util.ArrayList<java.lang.String>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getCurrentStorageVersionHash() {
    return this.currentStorageVersionHash;
  }
  public A withCurrentStorageVersionHash(java.lang.String currentStorageVersionHash) {
    this.currentStorageVersionHash=currentStorageVersionHash; return (A) this;
  }
  public java.lang.Boolean hasCurrentStorageVersionHash() {
    return this.currentStorageVersionHash != null;
  }
  
  /**
   * Method is deprecated. use withCurrentStorageVersionHash instead.
   */
  @java.lang.Deprecated
  public A withNewCurrentStorageVersionHash(java.lang.String arg0) {
    return (A)withCurrentStorageVersionHash(new String(arg0));
  }
  public java.lang.String getLastHeartbeatTime() {
    return this.lastHeartbeatTime;
  }
  public A withLastHeartbeatTime(java.lang.String lastHeartbeatTime) {
    this.lastHeartbeatTime=lastHeartbeatTime; return (A) this;
  }
  public java.lang.Boolean hasLastHeartbeatTime() {
    return this.lastHeartbeatTime != null;
  }
  
  /**
   * Method is deprecated. use withLastHeartbeatTime instead.
   */
  @java.lang.Deprecated
  public A withNewLastHeartbeatTime(java.lang.String arg0) {
    return (A)withLastHeartbeatTime(new String(arg0));
  }
  public A addToPersistedStorageVersionHashes(java.lang.Integer index,java.lang.String item) {
    if (this.persistedStorageVersionHashes == null) {this.persistedStorageVersionHashes = new java.util.ArrayList<java.lang.String>();}
    this.persistedStorageVersionHashes.add(index, item);
    return (A)this;
  }
  public A setToPersistedStorageVersionHashes(java.lang.Integer index,java.lang.String item) {
    if (this.persistedStorageVersionHashes == null) {this.persistedStorageVersionHashes = new java.util.ArrayList<java.lang.String>();}
    this.persistedStorageVersionHashes.set(index, item); return (A)this;
  }
  public A addToPersistedStorageVersionHashes(java.lang.String... items) {
    if (this.persistedStorageVersionHashes == null) {this.persistedStorageVersionHashes = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.persistedStorageVersionHashes.add(item);} return (A)this;
  }
  public A addAllToPersistedStorageVersionHashes(java.util.Collection<java.lang.String> items) {
    if (this.persistedStorageVersionHashes == null) {this.persistedStorageVersionHashes = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.persistedStorageVersionHashes.add(item);} return (A)this;
  }
  public A removeFromPersistedStorageVersionHashes(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.persistedStorageVersionHashes!= null){ this.persistedStorageVersionHashes.remove(item);}} return (A)this;
  }
  public A removeAllFromPersistedStorageVersionHashes(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.persistedStorageVersionHashes!= null){ this.persistedStorageVersionHashes.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getPersistedStorageVersionHashes() {
    return this.persistedStorageVersionHashes;
  }
  public java.lang.String getPersistedStorageVersionHash(java.lang.Integer index) {
    return this.persistedStorageVersionHashes.get(index);
  }
  public java.lang.String getFirstPersistedStorageVersionHash() {
    return this.persistedStorageVersionHashes.get(0);
  }
  public java.lang.String getLastPersistedStorageVersionHash() {
    return this.persistedStorageVersionHashes.get(persistedStorageVersionHashes.size() - 1);
  }
  public java.lang.String getMatchingPersistedStorageVersionHash(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: persistedStorageVersionHashes) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingPersistedStorageVersionHash(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: persistedStorageVersionHashes) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withPersistedStorageVersionHashes(java.util.List<java.lang.String> persistedStorageVersionHashes) {
    if (persistedStorageVersionHashes != null) {this.persistedStorageVersionHashes = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : persistedStorageVersionHashes){this.addToPersistedStorageVersionHashes(item);}} else { this.persistedStorageVersionHashes = null;} return (A) this;
  }
  public A withPersistedStorageVersionHashes(java.lang.String... persistedStorageVersionHashes) {
    if (this.persistedStorageVersionHashes != null) {this.persistedStorageVersionHashes.clear();}
    if (persistedStorageVersionHashes != null) {for (java.lang.String item :persistedStorageVersionHashes){ this.addToPersistedStorageVersionHashes(item);}} return (A) this;
  }
  public java.lang.Boolean hasPersistedStorageVersionHashes() {
    return persistedStorageVersionHashes != null && !persistedStorageVersionHashes.isEmpty();
  }
  public A addNewPersistedStorageVersionHash(java.lang.String arg0) {
    return (A)addToPersistedStorageVersionHashes(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    StorageStateStatusFluentImpl that = (StorageStateStatusFluentImpl) o;
    if (currentStorageVersionHash != null ? !currentStorageVersionHash.equals(that.currentStorageVersionHash) :that.currentStorageVersionHash != null) return false;
    if (lastHeartbeatTime != null ? !lastHeartbeatTime.equals(that.lastHeartbeatTime) :that.lastHeartbeatTime != null) return false;
    if (persistedStorageVersionHashes != null ? !persistedStorageVersionHashes.equals(that.persistedStorageVersionHashes) :that.persistedStorageVersionHashes != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(currentStorageVersionHash,  lastHeartbeatTime,  persistedStorageVersionHashes,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-storageversionmigrator-5.12.1-sources.jar: io/fabric8/openshift/api/model/storageversionmigrator/v1alpha1/StorageStateStatusFluentImpl.java <==
package io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class StorageStateStatusFluentImpl<A extends io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateStatusFluent<A>{
  public StorageStateStatusFluentImpl() {
  }
  public StorageStateStatusFluentImpl(io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateStatus instance) {
    this.withCurrentStorageVersionHash(instance.getCurrentStorageVersionHash()); 
    this.withLastHeartbeatTime(instance.getLastHeartbeatTime()); 
    this.withPersistedStorageVersionHashes(instance.getPersistedStorageVersionHashes()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String currentStorageVersionHash;
  private java.lang.String lastHeartbeatTime;
  private java.util.List<java.lang.String> persistedStorageVersionHashes = new java.util.ArrayList<java.lang.String>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getCurrentStorageVersionHash() {
    return this.currentStorageVersionHash;
  }
  public A withCurrentStorageVersionHash(java.lang.String currentStorageVersionHash) {
    this.currentStorageVersionHash=currentStorageVersionHash; return (A) this;
  }
  public java.lang.Boolean hasCurrentStorageVersionHash() {
    return this.currentStorageVersionHash != null;
  }
  
  /**
   * Method is deprecated. use withCurrentStorageVersionHash instead.
   */
  @java.lang.Deprecated
  public A withNewCurrentStorageVersionHash(java.lang.String arg0) {
    return (A)withCurrentStorageVersionHash(new String(arg0));
  }
  public java.lang.String getLastHeartbeatTime() {
    return this.lastHeartbeatTime;
  }
  public A withLastHeartbeatTime(java.lang.String lastHeartbeatTime) {
    this.lastHeartbeatTime=lastHeartbeatTime; return (A) this;
  }
  public java.lang.Boolean hasLastHeartbeatTime() {
    return this.lastHeartbeatTime != null;
  }
  
  /**
   * Method is deprecated. use withLastHeartbeatTime instead.
   */
  @java.lang.Deprecated
  public A withNewLastHeartbeatTime(java.lang.String arg0) {
    return (A)withLastHeartbeatTime(new String(arg0));
  }
  public A addToPersistedStorageVersionHashes(java.lang.Integer index,java.lang.String item) {
    if (this.persistedStorageVersionHashes == null) {this.persistedStorageVersionHashes = new java.util.ArrayList<java.lang.String>();}
    this.persistedStorageVersionHashes.add(index, item);
    return (A)this;
  }
  public A setToPersistedStorageVersionHashes(java.lang.Integer index,java.lang.String item) {
    if (this.persistedStorageVersionHashes == null) {this.persistedStorageVersionHashes = new java.util.ArrayList<java.lang.String>();}
    this.persistedStorageVersionHashes.set(index, item); return (A)this;
  }
  public A addToPersistedStorageVersionHashes(java.lang.String... items) {
    if (this.persistedStorageVersionHashes == null) {this.persistedStorageVersionHashes = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.persistedStorageVersionHashes.add(item);} return (A)this;
  }
  public A addAllToPersistedStorageVersionHashes(java.util.Collection<java.lang.String> items) {
    if (this.persistedStorageVersionHashes == null) {this.persistedStorageVersionHashes = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.persistedStorageVersionHashes.add(item);} return (A)this;
  }
  public A removeFromPersistedStorageVersionHashes(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.persistedStorageVersionHashes!= null){ this.persistedStorageVersionHashes.remove(item);}} return (A)this;
  }
  public A removeAllFromPersistedStorageVersionHashes(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.persistedStorageVersionHashes!= null){ this.persistedStorageVersionHashes.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getPersistedStorageVersionHashes() {
    return this.persistedStorageVersionHashes;
  }
  public java.lang.String getPersistedStorageVersionHash(java.lang.Integer index) {
    return this.persistedStorageVersionHashes.get(index);
  }
  public java.lang.String getFirstPersistedStorageVersionHash() {
    return this.persistedStorageVersionHashes.get(0);
  }
  public java.lang.String getLastPersistedStorageVersionHash() {
    return this.persistedStorageVersionHashes.get(persistedStorageVersionHashes.size() - 1);
  }
  public java.lang.String getMatchingPersistedStorageVersionHash(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: persistedStorageVersionHashes) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingPersistedStorageVersionHash(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: persistedStorageVersionHashes) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withPersistedStorageVersionHashes(java.util.List<java.lang.String> persistedStorageVersionHashes) {
    if (persistedStorageVersionHashes != null) {this.persistedStorageVersionHashes = new java.util.ArrayList(); for (java.lang.String item : persistedStorageVersionHashes){this.addToPersistedStorageVersionHashes(item);}} else { this.persistedStorageVersionHashes = null;} return (A) this;
  }
  public A withPersistedStorageVersionHashes(java.lang.String... persistedStorageVersionHashes) {
    if (this.persistedStorageVersionHashes != null) {this.persistedStorageVersionHashes.clear();}
    if (persistedStorageVersionHashes != null) {for (java.lang.String item :persistedStorageVersionHashes){ this.addToPersistedStorageVersionHashes(item);}} return (A) this;
  }
  public java.lang.Boolean hasPersistedStorageVersionHashes() {
    return persistedStorageVersionHashes != null && !persistedStorageVersionHashes.isEmpty();
  }
  public A addNewPersistedStorageVersionHash(java.lang.String arg0) {
    return (A)addToPersistedStorageVersionHashes(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    StorageStateStatusFluentImpl that = (StorageStateStatusFluentImpl) o;
    if (currentStorageVersionHash != null ? !currentStorageVersionHash.equals(that.currentStorageVersionHash) :that.currentStorageVersionHash != null) return false;
    if (lastHeartbeatTime != null ? !lastHeartbeatTime.equals(that.lastHeartbeatTime) :that.lastHeartbeatTime != null) return false;
    if (persistedStorageVersionHashes != null ? !persistedStorageVersionHashes.equals(that.persistedStorageVersionHashes) :that.persistedStorageVersionHashes != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(currentStorageVersionHash,  lastHeartbeatTime,  persistedStorageVersionHashes,  additionalProperties,  super.hashCode());
  }
  
}
